clear
set more off

*******************************************
*
* This .do file creates the analysis reported in "Personality and the Strength and Direction of Partisan Identification"
* Political Behavior
* Alan Gerber, Gregory Huber, David Doherty, Conor Dowling
*
* This version: January 26, 2012
*
*******************************************

local localpath=""

set mem 500m
use "`localpath'sourcedata\CCAP2008_Common.dta", clear

*******************************************
*
* RECODE VARIABLES
*
*******************************************
qui include 02_Sub_ConductReplicationAnalysis_codevars.do

*******************************************
*
* SET SAMPLE
*
*******************************************
qui logit female ideolcat_1 ideolcat_2 ideolcat_4 ideolcat_5 b_strpid7 b_strpid5 b_pid7 abortion civilunion healthcare taxes r_black r_hispanic r_other age age2 inccat_* educC_* BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness state*
gen insample=e(sample)
keep if insample==1

*******************************************
*
* A COUPLE OTHER VARIABLES NEEDED (SET WITHIN SELECTED SAMPLE)
*
*******************************************
gen weakratherlean=.
replace weakratherlean=1 if b_strpid7==2
replace weakratherlean=0 if b_strpid7==1
label var weakratherlean "Weak Identifier rather than Leaner (1=Weak) [Baseline wave]"

gen amongRstrpid=.
replace amongRstrpid=b_strpid5-1 if b_pid5<0
label var amongRstrpid "Among Republicans, 2-point strength of PID (1=Strong; 0=Leaner/Weak) [Baseline wave]"
gen amongDstrpid=.
replace amongDstrpid=b_strpid5-1 if b_pid5>0
label var amongDstrpid "Among Democrats, 2-point strength of PID (1=Strong; 0=Leaner/Weak) [Baseline wave]"

*******************************************
*
* ANALYSIS
*
*******************************************
*** CORRELATION BTW PID AND IDEOLOGY
corr b_pid7 b_ideol if insample==1 [aw=weight]


*** TIPI ITEM CORRELATIONS (FN 8)
corr  b_p_extraverted b_p_reserved_R if insample==1 [aw=weight]
corr  b_p_critical_R b_p_sympathetic if insample==1 [aw=weight]
corr  b_p_dependable b_p_disorganized_R if insample==1 [aw=weight]
corr  b_p_calm b_p_anxious_R if insample==1 [aw=weight]
corr  b_p_open b_p_conventional_R if insample==1 [aw=weight]


*** CORRELATIONS BETWEEN BIG FIVE MEASURES (TABLE 7)
corr BF_extraversion BF_agreeableness BF_conscientiousness BF_stability BF_openness if insample==1 [aw=weight]


*** SUMMARY STATS (TABLE 3)
*Capture here because outsum fails in stata 12
cap outsum BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness b_pid7 b_ideol b_strpid7 b_repaffil b_strpid5 b_strpid5_alt strideol female r_black r_hispanic r_other age income incomemis educ if insample==1 [aw=psweight] using "logs\Table3.out", bracket replace


*** DIRECTIONAL PID AND IDEOLOGY (TABLE 4)
qui ologit b_pid7 female r_black r_hispanic r_other age age2 inccat_* educC_* BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness state* if insample==1 [pw=psweight], cluster(profile66)
test BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness 
outreg BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness female r_black r_hispanic r_other age age2 using "logs\Table4.out", se addstat("F-test: Big Five", r(p)) adec(3) bracket rdec(3) replace

qui ologit b_ideol female r_black r_hispanic r_other age age2 inccat_* educC_* BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness state* if insample==1 [pw=psweight], cluster(profile66)
test BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness 
outreg BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness female r_black r_hispanic r_other age age2 using "logs\Table4.out", se addstat("F-test: Big Five", r(p)) adec(3) bracket rdec(3) append

qui ologit b_pid7 ideolcat_1 ideolcat_2 ideolcat_4 ideolcat_5 female r_black r_hispanic r_other age age2 inccat_* educC_* BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness state* if insample==1 [pw=psweight], cluster(profile66)
test BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness 
outreg BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness female r_black r_hispanic r_other age age2 using "logs\Table4.out", se addstat("F-test: Big Five", r(p)) adec(3) bracket rdec(3) append


*** STRENGTH OF PID (TABLE 5)
qui ologit b_strpid7 female r_black r_hispanic r_other age age2 inccat_* educC_* BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness state* if insample==1 [aw=psweight], cluster(profile66)
qui test BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness 
outreg BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness female r_black r_hispanic r_other age age2 using "logs\Table5.out", se addstat("F-test: Big Five", r(p)) adec(3) bracket rdec(3) replace 

qui ologit b_strpid7 female r_black r_hispanic r_other age age2 inccat_* educC_* ideolcat_1 ideolcat_2 ideolcat_4 ideolcat_5 BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness state* if insample==1 [aw=psweight], cluster(profile66)
qui test BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness 
outreg BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness female r_black r_hispanic r_other age age2 using "logs\Table5.out", se addstat("F-test: Big Five", r(p)) adec(3) bracket rdec(3) append 

qui ologit b_strpid7 female r_black r_hispanic r_other age age2 inccat_* educC_* abortionD_* civilD_* healthD_* taxesD_* BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness state* if insample==1 [aw=psweight], cluster(profile66)
qui test BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness 
outreg BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness female r_black r_hispanic r_other age age2 using "logs\Table5.out", se addstat("F-test: Big Five", r(p)) adec(3) bracket rdec(3) append 

qui ologit b_strpid7 female r_black r_hispanic r_other age age2 inccat_* educC_* ideolcat_1 ideolcat_2 ideolcat_4 ideolcat_5 abortionD_* civilD_* healthD_* taxesD_* BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness state* if insample==1 [aw=psweight], cluster(profile66)
qui test BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness 
outreg BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness female r_black r_hispanic r_other age age2 using "logs\Table5.out", se addstat("F-test: Big Five", r(p)) adec(3) bracket rdec(3) append 

qui foreach varofinterest in BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness inccat_11 female {
 *For income category, set delta to 1.
 if "`varofinterest'"~="inccat_11" & "`varofinterest'"~="female"{
  qui summ `varofinterest' if e(sample)  [aweight=psweight]
  local sd2=`r(sd)'*2
  prchange `varofinterest', x(inccat_8==1 age=48 age2=23.04 BF_extraversion=.52 BF_agreeableness=.71 BF_conscientiousness=.77 BF_stability=.68 BF_openness=.70 stateC_5=1) rest(min) fromto delta(`sd2')
 }
 else {
  local sd2=1
  prchange `varofinterest', x(age=48 age2=23.04 BF_extraversion=.52 BF_agreeableness=.71 BF_conscientiousness=.77 BF_stability=.68 BF_openness=.70 stateC_5=1) rest(min) fromto delta(`sd2')
 } 
 matrix base=r(predval)
 matrix base=base[1,4]
 matrix mfx=r(change3)
 if "`varofinterest'"~="inccat_11" & "`varofinterest'"~="female"{
  matrix submfx=mfx[9,1]
 }
 else{
  matrix submfx=mfx[6,1]
 }
 if "`varofinterest'"=="BF_extraversion" {
  matrix finalmfx1=base
  matrix finalmfx1=finalmfx1\submfx
  }
  else {
  matrix finalmfx1=finalmfx1\submfx
  }
}

qui logit b_repaffil female r_black r_hispanic r_other age age2 inccat_* educC_* ideolcat_1 ideolcat_2 ideolcat_4 ideolcat_5 abortionD_* civilD_* healthD_* taxesD_* BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness state* if insample==1 [pw=psweight], cluster(profile66)
qui test BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness 
outreg BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness female r_black r_hispanic r_other age age2 using "logs\Table5.out", se addstat("F-test: Big Five", r(p)) adec(3) bracket rdec(3) append

qui foreach varofinterest in BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness inccat_11 female {
 *For income category, set delta to 1.
 if "`varofinterest'"~="inccat_11" & "`varofinterest'"~="female"{
  qui summ `varofinterest' if e(sample)  [aweight=psweight]
  local sd2=`r(sd)'*2
  prchange `varofinterest', x(inccat_8==1 age=48 age2=23.04 BF_extraversion=.52 BF_agreeableness=.71 BF_conscientiousness=.77 BF_stability=.68 BF_openness=.70 stateC_5=1) rest(min) fromto delta(`sd2')
 }
 else {
  local sd2=1
  prchange `varofinterest', x(age=48 age2=23.04 BF_extraversion=.52 BF_agreeableness=.71 BF_conscientiousness=.77 BF_stability=.68 BF_openness=.70 stateC_5=1) rest(min) fromto delta(`sd2')
 } 
 matrix base=r(predval)
 matrix base=base[1,2]
 matrix mfx=r(change)
 if "`varofinterest'"~="inccat_11" & "`varofinterest'"~="female"{
  matrix submfx=mfx[9,1]
 }
 else{
  matrix submfx=mfx[6,1]
 }
 if "`varofinterest'"=="BF_extraversion" {
  matrix finalmfx2=base
  matrix finalmfx2=finalmfx2\submfx
  }
  else {
  matrix finalmfx2=finalmfx2\submfx
  }
}

qui ologit b_strpid5 female r_black r_hispanic r_other age age2 inccat_* educC_* ideolcat_1 ideolcat_2 ideolcat_4 ideolcat_5 abortionD_* civilD_* healthD_* taxesD_* BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness state* if insample==1 [aw=psweight], cluster(profile66)
qui test BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness 
outreg BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness female r_black r_hispanic r_other age age2 using "logs\Table5.out", se addstat("F-test: Big Five", r(p)) adec(3) bracket rdec(3) append 

qui ologit b_strpid5_alt female r_black r_hispanic r_other age age2 inccat_* educC_* ideolcat_1 ideolcat_2 ideolcat_4 ideolcat_5 abortionD_* civilD_* healthD_* taxesD_* BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness state* if insample==1 [aw=psweight], cluster(profile66)
qui test BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness 
outreg BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness female r_black r_hispanic r_other age age2 using "logs\Table5.out", se addstat("F-test: Big Five", r(p)) adec(3) bracket rdec(3) append 


*** STRENGTH OF IDEOLOGY (FN 13)
qui ologit strideol female r_black r_hispanic r_other age age2 inccat_* educC_* BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness state* if insample==1 [aw=psweight], cluster(profile66)
qui test BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness 
outreg BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness female r_black r_hispanic r_other age age2 using "logs\Table5alt_ideol.out", se addstat("F-test: Big Five", r(p)) adec(3) bracket rdec(3) replace

qui ologit strideol female r_black r_hispanic r_other age age2 inccat_* educC_* PID_1 PID_2 PID_3 PID_5 PID_6 PID_7 BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness state* if insample==1 [aw=psweight], cluster(profile66)
qui test BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness 
outreg BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness female r_black r_hispanic r_other age age2 using "logs\Table5alt_ideol.out", se addstat("F-test: Big Five", r(p)) adec(3) bracket rdec(3) append 

qui ologit strideol female r_black r_hispanic r_other age age2 inccat_* educC_* abortionD_* civilD_* healthD_* taxesD_* BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness state* if insample==1 [aw=psweight], cluster(profile66)
qui test BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness 
outreg BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness female r_black r_hispanic r_other age age2 using "logs\Table5alt_ideol.out", se addstat("F-test: Big Five", r(p)) adec(3) bracket rdec(3) append 

qui ologit strideol female r_black r_hispanic r_other age age2 inccat_* educC_* PID_1 PID_2 PID_3 PID_5 PID_6 PID_7 abortionD_* civilD_* healthD_* taxesD_* BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness state* if insample==1 [aw=psweight], cluster(profile66)
qui test BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness 
outreg BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness female r_black r_hispanic r_other age age2 using "logs\Table5alt_ideol.out", se addstat("F-test: Big Five", r(p)) adec(3) bracket rdec(3) append 


*** MARGINAL EFFECTS (TABLE 6)
matrix allmfx=finalmfx1,finalmfx2
matrix list allmfx
svmat allmfx, names(t6mfx)
outsheet t6mfx* using logs\table6mfx.csv, comma replace
drop t6mfx*


*** NO EDUCATION/INCOME CONTROLS ROBUSTNESS (TABLE 8 - DIRECTIONAL PID AND IDEOLOGY)
qui ologit b_pid7 female r_black r_hispanic r_other age age2 BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness state* if insample==1 [pw=psweight], cluster(profile66)
test BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness 
outreg BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness female r_black r_hispanic r_other age age2 using "logs\Table8.out", se addstat("F-test: Big Five", r(p)) adec(3) bracket rdec(3) replace

qui ologit b_ideol female r_black r_hispanic r_other age age2 BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness state* if insample==1 [pw=psweight], cluster(profile66)
test BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness 
outreg BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness female r_black r_hispanic r_other age age2 using "logs\Table8.out", se addstat("F-test: Big Five", r(p)) adec(3) bracket rdec(3) append


*** NO EDUCATION/INCOME CONTROLS ROBUSTNESS (TABLE 9 - STRENGTH OF PID)
qui ologit b_strpid7 female r_black r_hispanic r_other age age2 BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness state* if insample==1 [aw=psweight], cluster(profile66)
qui test BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness 
outreg BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness female r_black r_hispanic r_other age age2 using "logs\Table9.out", se addstat("F-test: Big Five", r(p)) adec(3) bracket rdec(3) replace 

qui ologit b_strpid7 female r_black r_hispanic r_other age age2 ideolcat_1 ideolcat_2 ideolcat_4 ideolcat_5 BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness state* if insample==1 [aw=psweight], cluster(profile66)
qui test BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness 
outreg BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness female r_black r_hispanic r_other age age2 using "logs\Table9.out", se addstat("F-test: Big Five", r(p)) adec(3) bracket rdec(3) append 

qui ologit b_strpid7 female r_black r_hispanic r_other age age2 abortionD_* civilD_* healthD_* taxesD_* BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness state* if insample==1 [aw=psweight], cluster(profile66)
qui test BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness 
outreg BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness female r_black r_hispanic r_other age age2 using "logs\Table9.out", se addstat("F-test: Big Five", r(p)) adec(3) bracket rdec(3) append 

qui ologit b_strpid7 female r_black r_hispanic r_other age age2 ideolcat_1 ideolcat_2 ideolcat_4 ideolcat_5 abortionD_* civilD_* healthD_* taxesD_* BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness state* if insample==1 [aw=psweight], cluster(profile66)
qui test BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness 
outreg BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness female r_black r_hispanic r_other age age2 using "logs\Table9.out", se addstat("F-test: Big Five", r(p)) adec(3) bracket rdec(3) append 

qui logit b_repaffil female r_black r_hispanic r_other age age2 ideolcat_1 ideolcat_2 ideolcat_4 ideolcat_5 abortionD_* civilD_* healthD_* taxesD_* BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness state* if insample==1 [pw=psweight], cluster(profile66)
qui test BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness 
outreg BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness female r_black r_hispanic r_other age age2 using "logs\Table9.out", se addstat("F-test: Big Five", r(p)) adec(3) bracket rdec(3) append

qui ologit b_strpid5 female r_black r_hispanic r_other age age2 ideolcat_1 ideolcat_2 ideolcat_4 ideolcat_5 abortionD_* civilD_* healthD_* taxesD_* BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness state* if insample==1 [aw=psweight], cluster(profile66)
qui test BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness 
outreg BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness female r_black r_hispanic r_other age age2 using "logs\Table9.out", se addstat("F-test: Big Five", r(p)) adec(3) bracket rdec(3) append 

qui ologit b_strpid5_alt female r_black r_hispanic r_other age age2 ideolcat_1 ideolcat_2 ideolcat_4 ideolcat_5 abortionD_* civilD_* healthD_* taxesD_* BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness state* if insample==1 [aw=psweight], cluster(profile66)
qui test BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness 
outreg BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness female r_black r_hispanic r_other age age2 using "logs\Table9.out", se addstat("F-test: Big Five", r(p)) adec(3) bracket rdec(3) append 


*** NO EDUCATION/INCOME CONTROLS ROBUSTNESS (NOT REPORTED - STRENGTH OF IDEOLOGY)
qui ologit strideol female r_black r_hispanic r_other age age2 BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness state* if insample==1 [aw=psweight], cluster(profile66)
qui test BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness 
outreg BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness female r_black r_hispanic r_other age age2 using "logs\robustness_str_ideol_noeducinc.out", se addstat("F-test: Big Five", r(p)) adec(3) bracket rdec(3) replace 

qui ologit strideol female r_black r_hispanic r_other age age2 PID_1 PID_2 PID_3 PID_5 PID_6 PID_7 BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness state* if insample==1 [aw=psweight], cluster(profile66)
qui test BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness 
outreg BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness female r_black r_hispanic r_other age age2 using "logs\robustness_str_ideol_noeducinc.out", se addstat("F-test: Big Five", r(p)) adec(3) bracket rdec(3) append 

qui ologit strideol female r_black r_hispanic r_other age age2 abortionD_* civilD_* healthD_* taxesD_* BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness state* if insample==1 [aw=psweight], cluster(profile66)
qui test BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness 
outreg BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness female r_black r_hispanic r_other age age2 using "logs\robustness_str_ideol_noeducinc.out", se addstat("F-test: Big Five", r(p)) adec(3) bracket rdec(3) append 

qui ologit strideol female r_black r_hispanic r_other age age2 PID_1 PID_2 PID_3 PID_5 PID_6 PID_7 abortionD_* civilD_* healthD_* taxesD_* BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness state* if insample==1 [aw=psweight], cluster(profile66)
qui test BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness 
outreg BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness female r_black r_hispanic r_other age age2 using "logs\robustness_str_ideol_noeducinc.out", se addstat("F-test: Big Five", r(p)) adec(3) bracket rdec(3) append 


*** MEDIATION ANALYSIS: DOES IDEOLOGY MEDIATE RELATIONSHIP BETWEEN BIG FIVE AND DIRECTIONAL PID (REPORTED IN TEXT)
factor ideolcat_1 ideolcat_2 ideolcat_4 ideolcat_5 abortionD_* civilD_* healthD_* taxesD_*  [aw=psweight], factors(1)
rotate
predict ideol_scale
gen ideol_scale_str=abs(ideol_scale)
label var ideol_scale "Ideology (Factor Scale)"
label var ideol_scale_str "Strength of Ideology (Factor Scale)"

file open myfile using "logs\robustness_mediation_dirpid.csv", write replace 
foreach ideol_var in b_ideol ideol_scale {

qui reg b_pid7 BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness female r_black r_hispanic r_other age age2 inccat_* educC_* state* if insample==1 [aw=psweight], cluster(profile66)
local n=e(N)
matrix coef=e(b)
matrix se=e(V)
local counter=0
foreach i in extraversion agreeable conscientious stability openness{
local counter=`counter'+1
local `i'_dir=coef[1,`counter']
local `i'_dir_se=sqrt(se[`counter',`counter'])
}

qui reg `ideol_var' BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness female r_black r_hispanic r_other age age2 inccat_* educC_* state* if insample==1 [aw=psweight], cluster(profile66)
matrix coef=e(b)
matrix se=e(V)
local counter=0
foreach i in extraversion agreeable conscientious stability openness{
local counter=`counter'+1
local `i'_med=coef[1,`counter']
local `i'_med_se=sqrt(se[`counter',`counter'])
}

qui reg b_pid7 BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness `ideol_var' female r_black r_hispanic r_other age age2 inccat_* educC_* state* if insample==1 [aw=psweight], cluster(profile66)
matrix coef=e(b)
matrix se=e(V)
local counter=0
foreach i in extraversion agreeable conscientious stability openness{
local counter=`counter'+1
local `i'_tot=coef[1,`counter']
local `i'_tot_se=sqrt(se[`counter',`counter'])
}

qui reg b_pid7 `ideol_var' female r_black r_hispanic r_other age age2 inccat_* educC_* state* if insample==1 [aw=psweight], cluster(profile66)
matrix coef=e(b)
matrix se=e(V)
local mediator=coef[1,1]
local mediator_se=sqrt(se[1,1])

***write to CSV
file write myfile "Ideology Mediate Relationships between Big Five and Directional Party ID?" _n
file write myfile "Big Five,Direct Effect (unmediated),Mediated Effect,Indirect Effect, Z-Statistic, P-value" _n
foreach i in extraversion agreeable conscientious stability openness{
local var=proper("`i'")
local ind=``i'_dir'-``i'_tot'
local z=(``i'_med'*`mediator')/sqrt(abs(`mediator'^2*``i'_med_se'^2+``i'_med'^2*`mediator_se'^2))
local p=ttail(`n',abs(`z'))*2
file write myfile "`var',``i'_dir',``i'_tot',`ind', `z', `p'" _n
}
}
file close myfile


*** MEDIATION ANALYSIS: DOES STRENGTH OF IDEOLOGY MEDIATE RELATIONSHIP BETWEEN BIG FIVE AND STRENGTH OF PID? (FN 15)
file open myfile using "logs\robustness_mediation_strpid.csv", write replace 
foreach ideol_var in strideol ideol_scale_str {

qui reg b_strpid7 BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness female r_black r_hispanic r_other age age2 inccat_* educC_* state* if insample==1 [aw=psweight], cluster(profile66)
local n=e(N)
matrix coef=e(b)
matrix se=e(V)
local counter=0
foreach i in extraversion agreeable conscientious stability openness{
local counter=`counter'+1
local `i'_dir=coef[1,`counter']
local `i'_dir_se=sqrt(se[`counter',`counter'])
}

qui reg `ideol_var' BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness female r_black r_hispanic r_other age age2 inccat_* educC_* state* if insample==1 [aw=psweight], cluster(profile66)
matrix coef=e(b)
matrix se=e(V)
local counter=0
foreach i in extraversion agreeable conscientious stability openness{
local counter=`counter'+1
local `i'_med=coef[1,`counter']
local `i'_med_se=sqrt(se[`counter',`counter'])
}

qui reg b_strpid7 BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness `ideol_var' female r_black r_hispanic r_other age age2 inccat_* educC_* state* if insample==1 [aw=psweight], cluster(profile66)
matrix coef=e(b)
matrix se=e(V)
local counter=0
foreach i in extraversion agreeable conscientious stability openness{
local counter=`counter'+1
local `i'_tot=coef[1,`counter']
local `i'_tot_se=sqrt(se[`counter',`counter'])
}

qui reg b_strpid7 `ideol_var' female r_black r_hispanic r_other age age2 inccat_* educC_* state* if insample==1 [aw=psweight], cluster(profile66)
matrix coef=e(b)
matrix se=e(V)
local mediator=coef[1,1]
local mediator_se=sqrt(se[1,1])

***write to CSV
file write myfile "Strength of Ideology Mediate Relationships between Big Five and Strength of Party ID?" _n
file write myfile "Big Five,Direct Effect (unmediated),Mediated Effect,Indirect Effect, Z-Statistic, P-value" _n
foreach i in extraversion agreeable conscientious stability openness{
local var=proper("`i'")
local ind=``i'_dir'-``i'_tot'
local z=(``i'_med'*`mediator')/sqrt(abs(`mediator'^2*``i'_med_se'^2+``i'_med'^2*`mediator_se'^2))
local p=ttail(`n',abs(`z'))*2
file write myfile "`var',``i'_dir',``i'_tot',`ind', `z', `p'" _n
}
}
file close myfile


*** PARTISAN STABILITY ANALYSIS (TABLE 11)
gen partstab=abs(p_pid7-b_pid7)
label var partstab "Partisan Stability, post-election-baseline (0=No change; 6=Moved 6 points)"

gen chngpid=0 if partstab==0
replace chngpid=1 if partstab>0 & partstab!=.
label var chngpid "Changed partisanship, baseline-post-election (0=No change; 1=Change)"

egen stdpid=rowsd(b_pid7 m_pid7 s_pid7 o_pid7 p_pid7)
egen mis_stdpid=rmiss(b_pid7 m_pid7 s_pid7 o_pid7 p_pid7)
drop if mis_stdpid!=0
drop mis_stdpid
label var stdpid "Standard deviation of PID"

qui logit chngpid female ideolcat_1 ideolcat_2 ideolcat_4 ideolcat_5 b_strpid7 b_strpid5 b_pid7 p_pid7 stdpid abortion civilunion healthcare taxes r_black r_hispanic r_other age age2 inccat_* educC_* BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness state*
gen insample2=e(sample)
keep if insample2==1

**
*Partisan Stability (absolute value of post-baseline measure; ranges from 0 to 6)
**
qui ologit partstab female r_black r_hispanic r_other age age2 inccat_* educC_* BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness state* if insample==1 [aw=psweight], cluster(profile66)
qui test BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness 
outreg BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness female r_black r_hispanic r_other age age2 using "logs\Table11.out", se addstat("F-test: Big Five", r(p)) adec(3) bracket rdec(3) replace 

qui ologit partstab female r_black r_hispanic r_other age age2 inccat_* educC_* ideolcat_1 ideolcat_2 ideolcat_4 ideolcat_5 BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness state* if insample==1 [aw=psweight], cluster(profile66)
qui test BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness 
outreg BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness female r_black r_hispanic r_other age age2 using "logs\Table11.out", se addstat("F-test: Big Five", r(p)) adec(3) bracket rdec(3) append 

qui ologit partstab female r_black r_hispanic r_other age age2 inccat_* educC_* abortionD_* civilD_* healthD_* taxesD_* BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness state* if insample==1 [aw=psweight], cluster(profile66)
qui test BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness 
outreg BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness female r_black r_hispanic r_other age age2 using "logs\Table11.out", se addstat("F-test: Big Five", r(p)) adec(3) bracket rdec(3) append 

qui ologit partstab female r_black r_hispanic r_other age age2 inccat_* educC_* ideolcat_1 ideolcat_2 ideolcat_4 ideolcat_5 abortionD_* civilD_* healthD_* taxesD_* BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness state* if insample==1 [aw=psweight], cluster(profile66)
qui test BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness 
outreg BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness female r_black r_hispanic r_other age age2 using "logs\Table11.out", se addstat("F-test: Big Five", r(p)) adec(3) bracket rdec(3) append 

**
*Changed Partisanship Stability (post v. baseline; 0 if no change, 1 if change)
**
qui logit chngpid female r_black r_hispanic r_other age age2 inccat_* educC_* BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness state* if insample==1 [pw=psweight], cluster(profile66)
qui test BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness 
outreg BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness female r_black r_hispanic r_other age age2 using "logs\Table11.out", se addstat("F-test: Big Five", r(p)) adec(3) bracket rdec(3) append 

qui logit chngpid female r_black r_hispanic r_other age age2 inccat_* educC_* ideolcat_1 ideolcat_2 ideolcat_4 ideolcat_5 BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness state* if insample==1 [pw=psweight], cluster(profile66)
qui test BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness 
outreg BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness female r_black r_hispanic r_other age age2 using "logs\Table11.out", se addstat("F-test: Big Five", r(p)) adec(3) bracket rdec(3) append 

qui logit chngpid female r_black r_hispanic r_other age age2 inccat_* educC_* abortionD_* civilD_* healthD_* taxesD_* BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness state* if insample==1 [pw=psweight], cluster(profile66)
qui test BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness 
outreg BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness female r_black r_hispanic r_other age age2 using "logs\Table11.out", se addstat("F-test: Big Five", r(p)) adec(3) bracket rdec(3) append 

qui logit chngpid female r_black r_hispanic r_other age age2 inccat_* educC_* ideolcat_1 ideolcat_2 ideolcat_4 ideolcat_5 abortionD_* civilD_* healthD_* taxesD_* BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness state* if insample==1 [pw=psweight], cluster(profile66)
qui test BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness 
outreg BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness female r_black r_hispanic r_other age age2 using "logs\Table11.out", se addstat("F-test: Big Five", r(p)) adec(3) bracket rdec(3) append 

**
*Changed Partisanship Stability (post v. baseline; 0 if no change, 1 if change)
**
qui reg stdpid female r_black r_hispanic r_other age age2 inccat_* educC_* BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness state* if insample==1 [pw=psweight], cluster(profile66)
qui test BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness 
outreg BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness female r_black r_hispanic r_other age age2 using "logs\Table11.out", se addstat("F-test: Big Five", r(p)) adec(3) bracket rdec(3) append 

qui reg stdpid female r_black r_hispanic r_other age age2 inccat_* educC_* ideolcat_1 ideolcat_2 ideolcat_4 ideolcat_5 BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness state* if insample==1 [pw=psweight], cluster(profile66)
qui test BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness 
outreg BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness female r_black r_hispanic r_other age age2 using "logs\Table11.out", se addstat("F-test: Big Five", r(p)) adec(3) bracket rdec(3) append 

qui reg stdpid female r_black r_hispanic r_other age age2 inccat_* educC_* abortionD_* civilD_* healthD_* taxesD_* BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness state* if insample==1 [pw=psweight], cluster(profile66)
qui test BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness 
outreg BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness female r_black r_hispanic r_other age age2 using "logs\Table11.out", se addstat("F-test: Big Five", r(p)) adec(3) bracket rdec(3) append 

qui reg stdpid female r_black r_hispanic r_other age age2 inccat_* educC_* ideolcat_1 ideolcat_2 ideolcat_4 ideolcat_5 abortionD_* civilD_* healthD_* taxesD_* BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness state* if insample==1 [pw=psweight], cluster(profile66)
qui test BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness 
outreg BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness female r_black r_hispanic r_other age age2 using "logs\Table11.out", se addstat("F-test: Big Five", r(p)) adec(3) bracket rdec(3) append 


*** TEA PARTY FAVORABILITY (TABLE 10)
include 02_Sub_ConductReplicationAnalysis_teaparty.do
