****************************
*
* RECODE DEMOGRAPHIC VARIABLES
*
****************************

* State, drop if missing state--get rid of state 10 dominant category
drop if profile66==0 | profile66==.
quietly tab profile66, gen(stateC_)
drop stateC_10

* Female, drop if missing
recode profile54 (1=0) (2=1) (*=.), gen(female)
drop if female==.
label var female "Female = 1"

* Race, no missing
gen race = profile55 
label var profile55
gen r_black = 0 if race ~=.
replace r_black = 1 if race==2
label var r_black "Black = 1"
gen r_hispanic = 0 if race ~=.
replace r_hispanic = 1 if race==3
label var r_hispanic "Hispanic = 1"
gen r_other = 0 if race ~=.
replace r_other = 1 if race==4
replace r_other = 1 if race==5
replace r_other = 1 if race==6
replace r_other = 1 if race==7
replace r_other = 1 if race==8
label var r_other "Other (Native American,Asian,Mixed,Other) = 1"

* Education, drop missing
gen educ=profile57 
drop if educ==.
label var educ "Education (1=No HS; 6=Post-grad)"
tab educ, gen(educC_)
*drop category 3
label var educC_1 "Educ<HS"
label var educC_2 "Educ=HS"
drop educC_3
label var educC_4 "Educ=2 year college"
label var educC_5 "Educ=College"
label var educC_6 "Educ=Post Grad"

* Family Income
* Skipped/RF set to missing, plus indicator for missing
* Not asked is dropped/missing
rename profile59 Income
keep if Income<=15
tab Income if Income<=15, gen(inccat_)
*5 is 1 sd below median, to make calcuating mfx easier
drop inccat_5
rename Income profile59
gen income=(profile59-1)/14
gen incomemis = (income==1)
replace income = 1 if incomemis==1
label var incomemis "Income Refused"
label var income "Income 0-1, 1=RF"

* Age
* No missing values
gen age=2008-profile51 
label var age "Age (Years)"
gen age2=(age^2)/100
label var age2 "Age^2/100"

* TIPI (CONSTRUCT BIG FIVE ITEMS)
*personality - extraverted
gen b_p_extraverted=profile40
recode b_p_extraverted (8=.) (9=.)

*personality - critical 
gen b_p_critical=profile41 
recode b_p_critical (8=.) (9=.)

*personality - dependable
gen b_p_dependable=profile42 
recode b_p_dependable (8=.) (9=.)

*personality - anxious
gen b_p_anxious=profile43 
recode b_p_anxious (8=.) (9=.)

*personality - open to new experiences
gen b_p_open=profile44 
recode b_p_open (8=.) (9=.)

*personality - reserved
gen b_p_reserved=profile45 
recode b_p_reserved (8=.) (9=.)

*personality - sympathetic
gen b_p_sympathetic=profile46 
recode b_p_sympathetic (8=.) (9=.)

*personality - disorganized
gen b_p_disorganized=profile47 
recode b_p_disorganized (8=.) (9=.)

*personality - calm
gen b_p_calm=profile48 
recode b_p_calm (8=.) (9=.)

*personality - conventional
gen b_p_conventional=profile49 
recode b_p_conventional (8=.) (9=.)

***Items range from 0 to 1 -- higher values mean more of the trait

*Big Five - Extraversion
recode b_p_reserved (7=1) (6=2) (5=3) (4=4) (3=5) (2=6) (1=7), gen(b_p_reserved_R)
gen BF_extraversion = (((b_p_extraverted + b_p_reserved_R)/2)-1)/6
label var BF_extraversion "Extraversion (0-1)"

*Big Five - Agreeableness
recode b_p_critical (7=1) (6=2) (5=3) (4=4) (3=5) (2=6) (1=7), gen(b_p_critical_R)
gen BF_agreeableness = (((b_p_sympathetic + b_p_critical_R)/2)-1)/6
label var BF_agreeableness "Agreeableness (0-1)"

*Big Five - Conscientiousness
recode b_p_disorganized (7=1) (6=2) (5=3) (4=4) (3=5) (2=6) (1=7), gen(b_p_disorganized_R)
gen BF_conscientiousness = (((b_p_dependable + b_p_disorganized_R)/2)-1)/6
label var BF_conscientiousness "Conscientiousness (0-1)"

*Big Five - Emotional Stability
recode b_p_anxious (7=1) (6=2) (5=3) (4=4) (3=5) (2=6) (1=7), gen(b_p_anxious_R)
gen BF_stability = (((b_p_calm + b_p_anxious_R)/2)-1)/6
label var BF_stability "Emotional Stability (0-1)"

*Big Five - Openness to Experiences
recode b_p_conventional (7=1) (6=2) (5=3) (4=4) (3=5) (2=6) (1=7), gen(b_p_conventional_R)
gen BF_openness = (((b_p_open + b_p_conventional_R)/2)-1)/6
label var BF_openness "Openness (0-1)"

****************************
*
* OUTCOME VARIABLES
*
****************************
* PARTY ID
foreach i in b m s o p {
recode `i'cap8 (8=4) (98 99=.), gen(`i'_pid7)
replace `i'_pid7=-1*(`i'_pid7-4)
}
label var b_pid7 "7-Point Party ID (-3=SR;+3=SD) [Baseline wave]"
label var m_pid7 "7-Point Party ID (-3=SR;+3=SD) [March wave]"
label var s_pid7 "7-Point Party ID (-3=SR;+3=SD) [September wave]"
label var o_pid7 "7-Point Party ID (-3=SR;+3=SD) [October wave]"
label var p_pid7 "7-Point Party ID (-3=SR;+3=SD) [Post-election wave]"

recode b_pid7 (-3=-2) (-2 -1=-1) (0=0) (1 2=1) (3=2), gen(b_pid5)
label var b_pid5 "5-Point Party ID (-2=SR;+2=SD) [Baseline wave]"
recode b_pid7 (-3=-2) (-2 -1=-1) (0 1=0) (2=1) (3=2), gen(b_pid5_alt)
label var b_pid5_alt "5-Point Party ID (Independents/Leaners collapsed) [Baseline wave]"
tab b_pid7, gen(PID_)
drop PID_4
label var PID_1 "Reported PID: Strong Republican [Baseline wave]"
label var PID_2 "Reported PID: Weak Republican [Baseline wave]"
label var PID_3 "Reported PID: Lean  Republican [Baseline wave]"
label var PID_5 "Reported PID: Lean Democratic [Baseline wave]"
label var PID_6 "Reported PID: Weak Democratic [Baseline wave]"
label var PID_7 "Reported PID: Strong Democratic [Baseline wave]"
gen b_party_notsure=(bcap8==8)
label var b_party_notsure "Reported Party ID: Not Sure [Baseline wave]"

gen b_strpid7=abs(b_pid7)
label var b_strpid7 "4-Point Strength of Party ID (0-3) [Baseline wave]"

gen b_strpid5=abs(b_pid5)
label var b_strpid5 "3-Point Strength of Party ID (0-2) [Leaners/Weak collapsed] [Baseline wave]"

gen b_strpid5_alt=abs(b_pid5_alt)
label var b_strpid5_alt "3-Point Strength of Party ID (0-2) [Ind/Leaners collapsed] [Baseline wave]"

recode bcap8_3 (1 2=1) (3 4 5=0) (*=.), gen(b_repaffil)
label var b_repaffil "Affiliated w/major party? (1=yes) [Baseline wave]"

recode bcap700s (1=2) (2=1) (3=0) (4=-1) (5=-2) (6=0) (*=.), gen(b_ideol_withns)
label var b_ideol_withns "Self-Reported Ideology (-2=Very Cons.;2=Very Lib., NotSure=0)"

* IDEOLOGY
gen strideol=abs(b_ideol_withns)
label var strideol "3-Point Strength of Ideology (0-2)"

tab b_ideol_withns, gen(ideolcat_)
drop ideolcat_3
label var ideolcat_1 "Ideology=Very Conservative"
label var ideolcat_2 "Ideology=Conservative"
label var ideolcat_4 "Ideology=Liberal"
label var ideolcat_5 "Ideology=Very Liberal"

gen partyname=trim(lower(bcap8_3t))
gen thirdparty_ltarian=0
replace thirdparty_ltarian=1 if strpos(partyname,"liber")~=0
replace thirdparty_ltarian=1 if strpos(partyname,"lerber")~=0
replace thirdparty_ltarian=1 if strpos(partyname,"libet")~=0
replace thirdparty_ltarian=1 if strpos(partyname,"libre")~=0
replace thirdparty_ltarian=1 if strpos(partyname,"libra")~=0
replace thirdparty_ltarian=1 if strpos(partyname,"libri")~=0
replace thirdparty_ltarian=1 if strpos(partyname,"libertarian")~=0
replace thirdparty_ltarian=0 if strpos(partyname,"liberal")~=0
label var thirdparty_ltarian "Third Party: Libertarian (1=yes)  [Baseline wave]"

* IDEOLOGY DIMENSIONS
***ECONOMIC
recode bcap20 (1=1) (2=2) (3=3) (*=.)
gen healthcare=(bcap20-1)/2
label var healthcare "Individualist Health Care (0-1)"

recode bcap24 (1=1) (2=2) (3=3) (4=4) (*=.)
gen taxes=(bcap24-1)/3
label var taxes "Oppose Taxing the Rich (0-1)"

***SOCIAL
recode profile15 (1=1) (2=2) (3=3) (4=4) (*=.)
gen abortion=(profile15-1)/3
label var abortion "Against Abortion (0-1)"

recode profile19 (1=1) (2=2) (3=3) (4=4) (*=.)
gen civilunion=(profile19-1)/3
label var civilunion "Oppose Civil Unions (0-1)"

tab healthcare, gen(healthD_)
label var healthD_1 "Health Care: Government Mandate"
drop healthD_2
label var healthD_3 "Health Care: Free Market"

tab taxes, gen(taxesD_)
label var taxesD_1 "Tax Rich: Strongly Favor"
drop taxesD_2
label var taxesD_3 "Tax Rich: Somewhat Oppose"
label var taxesD_4 "Tax Rich: Strongly Oppose"

tab abortion, gen(abortionD_)
label var abortionD_1 "Abortion: No Restrictions"
drop abortionD_2
label var abortionD_3 "Abortion: Only Special Circumstances"
label var abortionD_4 "Abortion: Always Illegal"

tab civilunion, gen(civilD_)
label var civilD_1 "Civil Unions: Strongly Favor"
drop civilD_2
label var civilD_3 "Civil Unions: Somewhat Oppose"
label var civilD_4 "Civil Unions: Strongly Oppose"

****************************
*
* IDEOLOGY x BIG FIVE INTERACTIONS
*
****************************
foreach i in extraversion agreeableness conscientiousness stability openness{
gen Xideol_`i'= BF_`i'*b_ideol_withns
gen Xstrideol_`i'= BF_`i'*strideol
gen DXideol1_`i'=BF_`i'*ideolcat_1
gen DXideol2_`i'=BF_`i'*ideolcat_2
gen DXideol4_`i'=BF_`i'*ideolcat_4
gen DXideol5_`i'=BF_`i'*ideolcat_5

local bflabel: variable label BF_`i'
local bflabel=subinstr("`bflabel'"," (0-1)","",.)
label var Xideol_`i' "Ideology x `bflabel'"
label var Xstrideol_`i' "Str. Ideology x `bflabel'"
label var DXideol1_`i' "V. Conservative x `bflabel'"
label var DXideol2_`i' "Conservative x `bflabel'"
label var DXideol4_`i' "Liberal x `bflabel'"
label var DXideol5_`i' "V. Liberal x `bflabel'"
}
